Module cdp

Module cdp 

Structs

CdpElement
One element found via CDP Runtime.evaluate. Coordinates are viewport-relative (not screen-absolute).

Functions

find_elements
Find elements matching query in the frontmost Chrome tab.
is_available
Returns true if Chrome is listening on port 9222.
viewport_to_screen
Convert viewport-relative coordinates to screen-absolute coordinates.